@@ -2,6 +2,13 @@
 #and yet again August 1 to make it actually work!
 "describe.by" <-
 function (x,group=NULL,mat=FALSE,type=3,...) {               #data are x, grouping variable is group
+.Deprecated("describeBy", msg = "describe.by is deprecated.  Please use the describeBy function")
+answer <- describeBy(x=x,group=group,mat=mat,type=type,...)
+return(answer)}
+
+
+"describeBy" <-
+function (x,group=NULL,mat=FALSE,type=3,...) {               #data are x, grouping variable is group
 if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
 		answer <- by(x,group,describe,type=type,...)
